@@ -20,19 +20,18 @@ package org.jpmml.converter;
 
 import org.dmg.pmml.DataType;
 import org.dmg.pmml.Field;
-import org.dmg.pmml.FieldName;
 
 public class ContinuousFeature extends Feature {
 
 	public ContinuousFeature(PMMLEncoder encoder, Field<?> field){
-		this(encoder, field.getName(), field.getDataType());
+		this(encoder, field.requireName(), field.requireDataType());
 	}
 
 	public ContinuousFeature(PMMLEncoder encoder, Feature feature){
 		this(encoder, feature.getName(), feature.getDataType());
 	}
 
-	public ContinuousFeature(PMMLEncoder encoder, FieldName name, DataType dataType){
+	public ContinuousFeature(PMMLEncoder encoder, String name, DataType dataType){
 		super(encoder, name, dataType);
 	}
 
