@@ -18,6 +18,8 @@
  */
 package org.jpmml.converter;
 
+import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.regex.Matcher;
@@ -27,8 +29,6 @@ import java.util.stream.Collectors;
 import com.google.common.collect.Iterables;
 import org.dmg.pmml.DataType;
 import org.dmg.pmml.Entity;
-import org.dmg.pmml.FieldName;
-import org.dmg.pmml.FieldRef;
 import org.dmg.pmml.InlineTable;
 import org.dmg.pmml.MathContext;
 import org.dmg.pmml.MiningField;
@@ -36,6 +36,7 @@ import org.dmg.pmml.MiningSchema;
 import org.dmg.pmml.Model;
 import org.dmg.pmml.ModelStats;
 import org.dmg.pmml.ModelVerification;
+import org.dmg.pmml.NamespacePrefixes;
 import org.dmg.pmml.OpType;
 import org.dmg.pmml.Output;
 import org.dmg.pmml.OutputField;
@@ -53,18 +54,40 @@ public class ModelUtil {
 
 	static
 	public MathContext simplifyMathContext(MathContext mathContext){
-		return (MathContext.DOUBLE).equals(mathContext) ? null : mathContext;
+		return (mathContext == MathContext.DOUBLE) ? null : mathContext;
 	}
 
 	static
 	public MiningSchema createMiningSchema(Label label){
 		MiningSchema miningSchema = new MiningSchema();
 
-		if(label != null){
-			FieldName name = label.getName();
+		List<ScalarLabel> scalarLabels = null;
 
-			if(name != null){
-				MiningField miningField = createMiningField(name, MiningField.UsageType.TARGET);
+		if(label instanceof ScalarLabel){
+			ScalarLabel scalarLabel = (ScalarLabel)label;
+
+			scalarLabels = Collections.singletonList(scalarLabel);
+		} else
+
+		if(label instanceof MultiLabel){
+			MultiLabel multiLabel = (MultiLabel)label;
+
+			List<? extends Label> labels = multiLabel.getLabels();
+
+			scalarLabels = labels.stream()
+				.map(ScalarLabel.class::cast)
+				.collect(Collectors.toList());
+		} // End if
+
+		if(scalarLabels != null && !scalarLabels.isEmpty()){
+
+			for(ScalarLabel scalarLabel : scalarLabels){
+
+				if(scalarLabel.isAnonymous()){
+					continue;
+				}
+
+				MiningField miningField = createMiningField(scalarLabel.getName(), MiningField.UsageType.TARGET);
 
 				miningSchema.addMiningFields(miningField);
 			}
@@ -74,12 +97,12 @@ public class ModelUtil {
 	}
 
 	static
-	public MiningField createMiningField(FieldName name){
+	public MiningField createMiningField(String name){
 		return createMiningField(name, null);
 	}
 
 	static
-	public MiningField createMiningField(FieldName name, MiningField.UsageType usageType){
+	public MiningField createMiningField(String name, MiningField.UsageType usageType){
 		MiningField miningField = new MiningField(name)
 			.setUsageType(usageType);
 
@@ -88,10 +111,8 @@ public class ModelUtil {
 
 	static
 	public Targets createRescaleTargets(Number slope, Number intercept, ContinuousLabel continuousLabel){
-		FieldName name = continuousLabel.getName();
-
 		Target target = new Target()
-			.setField(name);
+			.setTargetField(continuousLabel.getName());
 
 		boolean rescaled = false;
 
@@ -131,20 +152,16 @@ public class ModelUtil {
 	}
 
 	static
-	public Output createPredictedOutput(FieldName name, OpType opType, DataType dataType, Transformation... transformations){
+	public Output createPredictedOutput(String name, OpType opType, DataType dataType, Transformation... transformations){
 		Output output = new Output();
 
-		OutputField outputField = new OutputField(name, opType, dataType)
-			.setResultFeature(ResultFeature.PREDICTED_VALUE)
+		OutputField outputField = createPredictedField(name, opType, dataType)
 			.setFinalResult(false);
 
 		output.addOutputFields(outputField);
 
 		for(Transformation transformation : transformations){
-			outputField = new OutputField(transformation.getName(outputField.getName()), transformation.getOpType(outputField.getOpType()), transformation.getDataType(outputField.getDataType()))
-				.setResultFeature(ResultFeature.TRANSFORMED_VALUE)
-				.setFinalResult(transformation.isFinalResult())
-				.setExpression(transformation.createExpression(new FieldRef(outputField.getName())));
+			outputField = transformation.createOutputField(outputField);
 
 			output.addOutputFields(outputField);
 		}
@@ -156,7 +173,7 @@ public class ModelUtil {
 	public Output createProbabilityOutput(MathContext mathContext, CategoricalLabel categoricalLabel){
 		DataType dataType = DataType.DOUBLE;
 
-		if((MathContext.FLOAT).equals(mathContext)){
+		if(mathContext == MathContext.FLOAT){
 			dataType = DataType.FLOAT;
 		}
 
@@ -175,11 +192,11 @@ public class ModelUtil {
 
 	static
 	public OutputField createAffinityField(DataType dataType, Object value){
-		return createAffinityField(FieldNameUtil.create("affinity", value), dataType, value);
+		return createAffinityField(FieldNameUtil.create(FieldNamePrefixes.AFFINITY, value), dataType, value);
 	}
 
 	static
-	public OutputField createAffinityField(FieldName name, DataType dataType, Object value){
+	public OutputField createAffinityField(String name, DataType dataType, Object value){
 		OutputField outputField = new OutputField(name, OpType.CONTINUOUS, dataType)
 			.setResultFeature(ResultFeature.AFFINITY)
 			.setValue(value);
@@ -195,15 +212,26 @@ public class ModelUtil {
 	}
 
 	static
-	public OutputField createEntityIdField(FieldName name){
-		OutputField outputField = new OutputField(name, OpType.CATEGORICAL, DataType.STRING)
+	public OutputField createEntityIdField(String name, DataType dataType){
+		OutputField outputField = new OutputField(name, OpType.CATEGORICAL, dataType)
 			.setResultFeature(ResultFeature.ENTITY_ID);
 
 		return outputField;
 	}
 
 	static
-	public OutputField createPredictedField(FieldName name, OpType opType, DataType dataType){
+	public OutputField createEntityIdField(String name, DataType dataType, List<?> values){
+		OutputField outputField = createEntityIdField(name, dataType);
+
+		if(values != null && !values.isEmpty()){
+			PMMLUtil.addValues(outputField, values);
+		}
+
+		return outputField;
+	}
+
+	static
+	public OutputField createPredictedField(String name, OpType opType, DataType dataType){
 		OutputField outputField = new OutputField(name, opType, dataType)
 			.setResultFeature(ResultFeature.PREDICTED_VALUE);
 
@@ -211,12 +239,23 @@ public class ModelUtil {
 	}
 
 	static
-	public OutputField createProbabilityField(DataType dataType, Object value){
-		return createProbabilityField(FieldNameUtil.create("probability", value), dataType, value);
+	public OutputField createPredictedField(String name, OpType opType, DataType dataType, List<?> values){
+		OutputField outputField = createPredictedField(name, opType, dataType);
+
+		if(values != null && !values.isEmpty()){
+			PMMLUtil.addValues(outputField, values);
+		}
+
+		return outputField;
 	}
 
 	static
-	public OutputField createProbabilityField(FieldName name, DataType dataType, Object value){
+	public OutputField createProbabilityField(DataType dataType, Object value){
+		return createProbabilityField(FieldNameUtil.create(FieldNamePrefixes.PROBABILITY, value), dataType, value);
+	}
+
+	static
+	public OutputField createProbabilityField(String name, DataType dataType, Object value){
 		OutputField outputField = new OutputField(name, OpType.CONTINUOUS, dataType)
 			.setResultFeature(ResultFeature.PROBABILITY)
 			.setValue(value);
@@ -231,6 +270,26 @@ public class ModelUtil {
 			.collect(Collectors.toList());
 	}
 
+	static
+	public OutputField createNeighborField(DataType dataType, int rank){
+		OutputField outputField = new OutputField(FieldNameUtil.create(FieldNamePrefixes.NEIGHBOR, rank), OpType.CATEGORICAL, dataType)
+			.setResultFeature(ResultFeature.ENTITY_ID)
+			.setRank(rank);
+
+		return outputField;
+	}
+
+	static
+	public List<OutputField> createNeighborFields(int count){
+		List<OutputField> result = new ArrayList<>();
+
+		for(int i = 0; i < count; i++){
+			result.add(createNeighborField(DataType.STRING, (i + 1)));
+		}
+
+		return result;
+	}
+
 	static
 	public ModelStats ensureModelStats(Model model){
 		ModelStats modelStats = model.getModelStats();
@@ -245,8 +304,8 @@ public class ModelUtil {
 	}
 
 	static
-	public VerificationField createVerificationField(FieldName name){
-		String tagName = name.getValue();
+	public VerificationField createVerificationField(String name){
+		String tagName = name;
 
 		// Replace "function(arg)" with "function_arg"
 		Matcher matcher = ModelUtil.FUNCTION_INVOCATION.matcher(tagName);
@@ -256,7 +315,7 @@ public class ModelUtil {
 
 		VerificationField verificationField = new VerificationField()
 			.setField(name)
-			.setColumn("data:" + XMLUtil.createTagName(tagName));
+			.setColumn(NamespacePrefixes.JPMML_INLINETABLE + ":" + XMLUtil.createTagName(tagName));
 
 		return verificationField;
 	}
