@@ -20,15 +20,14 @@ package org.jpmml.converter;
 
 import org.dmg.pmml.DataType;
 import org.dmg.pmml.Field;
-import org.dmg.pmml.FieldName;
 
 public class ObjectFeature extends Feature {
 
 	public ObjectFeature(PMMLEncoder encoder, Field<?> field){
-		this(encoder, field.getName(), field.getDataType());
+		this(encoder, field.requireName(), field.requireDataType());
 	}
 
-	public ObjectFeature(PMMLEncoder encoder, FieldName name, DataType dataType){
+	public ObjectFeature(PMMLEncoder encoder, String name, DataType dataType){
 		super(encoder, name, dataType);
 	}
 
