@@ -51,9 +51,9 @@ public class Schema {
 	}
 
 	public Schema toAnonymousSchema(){
-		Label label = getLabel();
+		ScalarLabel scalarLabel = (ScalarLabel)getLabel();
 
-		return toRelabeledSchema(label != null ? label.toAnonymousLabel() : null);
+		return toRelabeledSchema(scalarLabel != null ? scalarLabel.toAnonymousLabel() : null);
 	}
 
 	public Schema toAnonymousRegressorSchema(DataType dataType){
@@ -66,7 +66,7 @@ public class Schema {
 				throw new IllegalArgumentException();
 		}
 
-		Label label = new ContinuousLabel(null, dataType);
+		Label label = new ContinuousLabel(dataType);
 
 		return toRelabeledSchema(label);
 	}
