@@ -25,7 +25,6 @@ import java.util.Map;
 import java.util.Objects;
 
 import com.google.common.collect.Iterables;
-import org.dmg.pmml.FieldName;
 import org.dmg.pmml.FieldRef;
 import org.dmg.pmml.MathContext;
 import org.dmg.pmml.MiningFunction;
@@ -173,7 +172,7 @@ public class RegressionModelUtil {
 				CategoricalPredictor categoricalPredictor = categoricalPredictors.get(predictorKey);
 				if(categoricalPredictor == null){
 					categoricalPredictor = new CategoricalPredictor()
-						.setName(binaryFeature.getName())
+						.setField(binaryFeature.getName())
 						.setValue(binaryFeature.getValue())
 						.setCoefficient(coefficient);
 
@@ -183,7 +182,7 @@ public class RegressionModelUtil {
 				} else
 
 				{
-					categoricalPredictor.setCoefficient(ValueUtil.add(mathContext, categoricalPredictor.getCoefficient(), coefficient));
+					categoricalPredictor.setCoefficient(ValueUtil.add(mathContext, categoricalPredictor.requireCoefficient(), coefficient));
 				}
 			} else
 
@@ -195,7 +194,7 @@ public class RegressionModelUtil {
 				CategoricalPredictor categoricalPredictor = categoricalPredictors.get(predictorKey);
 				if(categoricalPredictor == null){
 					categoricalPredictor = new CategoricalPredictor()
-						.setName(booleanFeature.getName())
+						.setField(booleanFeature.getName())
 						.setValue(BooleanFeature.VALUE_TRUE)
 						.setCoefficient(coefficient);
 
@@ -205,14 +204,14 @@ public class RegressionModelUtil {
 				} else
 
 				{
-					categoricalPredictor.setCoefficient(ValueUtil.add(mathContext, categoricalPredictor.getCoefficient(), coefficient));
+					categoricalPredictor.setCoefficient(ValueUtil.add(mathContext, categoricalPredictor.requireCoefficient(), coefficient));
 				}
 			} else
 
 			if(feature instanceof ConstantFeature){
 				ConstantFeature constantFeature = (ConstantFeature)feature;
 
-				Number value = ValueUtil.add(mathContext, regressionTable.getIntercept(), ValueUtil.multiply(mathContext, coefficient, constantFeature.getValue()));
+				Number value = ValueUtil.add(mathContext, regressionTable.requireIntercept(), ValueUtil.multiply(mathContext, coefficient, constantFeature.getValue()));
 
 				regressionTable.setIntercept(value);
 			} else
@@ -230,7 +229,7 @@ public class RegressionModelUtil {
 					if(inputFeature instanceof ConstantFeature){
 						ConstantFeature constantFeature = (ConstantFeature)inputFeature;
 
-						Number value = ValueUtil.multiply(mathContext, predictorTerm.getCoefficient(), constantFeature.getValue());
+						Number value = ValueUtil.multiply(mathContext, predictorTerm.requireCoefficient(), constantFeature.getValue());
 
 						predictorTerm.setCoefficient(value);
 					} else
@@ -244,7 +243,7 @@ public class RegressionModelUtil {
 
 				List<FieldRef> fieldRefs = predictorTerm.getFieldRefs();
 				if(fieldRefs.size() == 0){
-					Number value = ValueUtil.add(mathContext, regressionTable.getIntercept(), predictorTerm.getCoefficient());
+					Number value = ValueUtil.add(mathContext, regressionTable.getIntercept(), predictorTerm.requireCoefficient());
 
 					regressionTable.setIntercept(value);
 				} else
@@ -253,8 +252,8 @@ public class RegressionModelUtil {
 					FieldRef fieldRef = Iterables.getOnlyElement(fieldRefs);
 
 					NumericPredictor numericPredictor = new NumericPredictor()
-						.setName(fieldRef.getField())
-						.setCoefficient(predictorTerm.getCoefficient());
+						.setField(fieldRef.requireField())
+						.setCoefficient(predictorTerm.requireCoefficient());
 
 					regressionTable.addNumericPredictors(numericPredictor);
 				} else
@@ -268,7 +267,7 @@ public class RegressionModelUtil {
 				PowerFeature powerFeature = (PowerFeature)feature;
 
 				NumericPredictor numericPredictor = new NumericPredictor()
-					.setName(powerFeature.getName())
+					.setField(powerFeature.getName())
 					.setExponent(powerFeature.getPower())
 					.setCoefficient(coefficient);
 
@@ -283,7 +282,7 @@ public class RegressionModelUtil {
 				NumericPredictor numericPredictor = numericPredictors.get(predictorKey);
 				if(numericPredictor == null){
 					numericPredictor = new NumericPredictor()
-						.setName(continuousFeature.getName())
+						.setField(continuousFeature.getName())
 						.setCoefficient(coefficient);
 
 					numericPredictors.put(predictorKey, numericPredictor);
@@ -292,7 +291,7 @@ public class RegressionModelUtil {
 				} else
 
 				{
-					numericPredictor.setCoefficient(ValueUtil.add(mathContext, numericPredictor.getCoefficient(), coefficient));
+					numericPredictor.setCoefficient(ValueUtil.add(mathContext, numericPredictor.requireCoefficient(), coefficient));
 				}
 			}
 		}
@@ -303,16 +302,16 @@ public class RegressionModelUtil {
 	static
 	private class PredictorKey {
 
-		private FieldName name = null;
+		private String name = null;
 
 		private Object value = null;
 
 
-		private PredictorKey(FieldName name){
+		private PredictorKey(String name){
 			this(name, null);
 		}
 
-		private PredictorKey(FieldName name, Object value){
+		private PredictorKey(String name, Object value){
 			this.name = name;
 			this.value = value;
 		}
