@@ -25,12 +25,12 @@ import java.util.Map;
 
 import org.dmg.pmml.DataField;
 import org.dmg.pmml.DataType;
-import org.dmg.pmml.FieldName;
 import org.dmg.pmml.MiningFunction;
 import org.dmg.pmml.OpType;
 import org.dmg.pmml.Output;
 import org.dmg.pmml.Predicate;
 import org.dmg.pmml.ScoreDistribution;
+import org.dmg.pmml.ScoreProbability;
 import org.dmg.pmml.SimplePredicate;
 import org.dmg.pmml.True;
 import org.dmg.pmml.tree.BranchNode;
@@ -50,7 +50,7 @@ public class BinaryTreeConverter extends TreeModelConverter<S4Object> {
 
 	private MiningFunction miningFunction = null;
 
-	private Map<FieldName, Integer> featureIndexes = new LinkedHashMap<>();
+	private Map<String, Integer> featureIndexes = new LinkedHashMap<>();
 
 
 	public BinaryTreeConverter(S4Object binaryTree){
@@ -89,7 +89,7 @@ public class BinaryTreeConverter extends TreeModelConverter<S4Object> {
 				throw new IllegalArgumentException();
 		}
 
-		output.addOutputFields(ModelUtil.createEntityIdField(FieldName.create("nodeId")));
+		output.addOutputFields(ModelUtil.createEntityIdField("nodeId", DataType.STRING));
 
 		TreeModel treeModel = encodeTreeModel(tree, schema)
 			.setOutput(output);
@@ -118,13 +118,13 @@ public class BinaryTreeConverter extends TreeModelConverter<S4Object> {
 
 			RStringVector targetCategories = levels.getStringElement(variableName);
 
-			dataField = encoder.createDataField(FieldName.create(variableName), OpType.CATEGORICAL, RExpUtil.getDataType(targetVariableClass.asScalar()), targetCategories.getValues());
+			dataField = encoder.createDataField(variableName, OpType.CATEGORICAL, RExpUtil.getDataType(targetVariableClass.asScalar()), targetCategories.getValues());
 		} else
 
 		if((Boolean.FALSE).equals(categorical)){
 			this.miningFunction = MiningFunction.REGRESSION;
 
-			dataField = encoder.createDataField(FieldName.create(variableName), OpType.CONTINUOUS, DataType.DOUBLE);
+			dataField = encoder.createDataField(variableName, OpType.CONTINUOUS, DataType.DOUBLE);
 		} else
 
 		{
@@ -147,7 +147,7 @@ public class BinaryTreeConverter extends TreeModelConverter<S4Object> {
 		RNumberVector<?> splitpoint = psplit.getNumericElement("splitpoint");
 		RStringVector variableName = psplit.getStringElement("variableName");
 
-		FieldName name = FieldName.create(variableName.asScalar());
+		String name = variableName.asScalar();
 
 		DataField dataField = encoder.getDataField(name);
 		if(dataField == null){
@@ -205,14 +205,14 @@ public class BinaryTreeConverter extends TreeModelConverter<S4Object> {
 		RNumberVector<?> splitpoint = psplit.getNumericElement("splitpoint");
 		RStringVector variableName = psplit.getStringElement("variableName");
 
-		if(ssplits.size() > 0){
+		if(!ssplits.isEmpty()){
 			throw new IllegalArgumentException();
 		}
 
 		Predicate leftPredicate;
 		Predicate rightPredicate;
 
-		FieldName name = FieldName.create(variableName.asScalar());
+		String name = variableName.asScalar();
 
 		Integer index = this.featureIndexes.get(name);
 		if(index == null){
@@ -295,11 +295,6 @@ public class BinaryTreeConverter extends TreeModelConverter<S4Object> {
 
 	static
 	private Node encodeRegressionScore(Node node, RDoubleVector probabilities){
-
-		if(probabilities.size() != 1){
-			throw new IllegalArgumentException();
-		}
-
 		Double probability = probabilities.asScalar();
 
 		node.setScore(probability);
@@ -329,7 +324,7 @@ public class BinaryTreeConverter extends TreeModelConverter<S4Object> {
 				maxProbability = probability;
 			}
 
-			ScoreDistribution scoreDistribution = new ScoreDistribution(value, probability);
+			ScoreDistribution scoreDistribution = new ScoreProbability(value, null, probability);
 
 			scoreDistributions.add(scoreDistribution);
 		}
