@@ -24,16 +24,17 @@ import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.stream.Collectors;
 
 import com.google.common.base.Function;
 import com.google.common.collect.Lists;
-import org.dmg.pmml.FieldName;
 import org.dmg.pmml.Model;
 import org.dmg.pmml.PMML;
 import org.dmg.pmml.VerificationField;
-import org.jpmml.converter.Label;
+import org.jpmml.converter.Feature;
+import org.jpmml.converter.FeatureImportanceMap;
+import org.jpmml.converter.ModelEncoder;
 import org.jpmml.converter.ModelUtil;
+import org.jpmml.converter.ScalarLabel;
 import org.jpmml.converter.Schema;
 
 abstract
@@ -49,6 +50,26 @@ public class ModelConverter<R extends RExp> extends Converter<R> {
 	abstract
 	public Model encodeModel(Schema schema);
 
+	public Model encode(Schema schema){
+		Model model = encodeModel(schema);
+
+		if(this instanceof HasFeatureImportances){
+			HasFeatureImportances hasFeatureImportances = (HasFeatureImportances)this;
+
+			FeatureImportanceMap featureImportances = hasFeatureImportances.getFeatureImportances(schema);
+			if(featureImportances != null && !featureImportances.isEmpty()){
+				ModelEncoder encoder = (ModelEncoder)schema.getEncoder();
+
+				Collection<Map.Entry<Feature, Number>> entries = featureImportances.entrySet();
+				for(Map.Entry<Feature, Number> entry : entries){
+					encoder.addFeatureImportance(model, entry.getKey(), entry.getValue());
+				}
+			}
+		}
+
+		return model;
+	}
+
 	@Override
 	public PMML encodePMML(RExpEncoder encoder){
 		RExp object = getObject();
@@ -71,7 +92,7 @@ public class ModelConverter<R extends RExp> extends Converter<R> {
 
 		Schema schema = encoder.createSchema();
 
-		Model model = encodeModel(schema);
+		Model model = encode(schema);
 
 		verification:
 		if(verification != null){
@@ -89,20 +110,20 @@ public class ModelConverter<R extends RExp> extends Converter<R> {
 			} // End if
 
 			if(targetValues != null && outputValues == null){
-				Label label = schema.getLabel();
+				ScalarLabel scalarLabel = (ScalarLabel)schema.getLabel();
 
-				FieldName name = label.getName();
+				String name = scalarLabel.getName();
 
 				Collection<VerificationField> verificationFields = data.keySet();
 				for(Iterator<VerificationField> verificationFieldIt = verificationFields.iterator(); verificationFieldIt.hasNext(); ){
 					VerificationField verificationField = verificationFieldIt.next();
 
-					if((verificationField.getField()).equals(name)){
+					if((verificationField.requireField()).equals(name)){
 						verificationFieldIt.remove();
 					}
 				}
 
-				data.putResultData(encodeTargetValues(targetValues, label));
+				data.putResultData(encodeTargetValues(targetValues, scalarLabel));
 			} else
 
 			if(outputValues != null){
@@ -125,9 +146,9 @@ public class ModelConverter<R extends RExp> extends Converter<R> {
 		return encodeVerificationData(dataFrame);
 	}
 
-	protected Map<VerificationField, List<?>> encodeTargetValues(RGenericVector dataFrame, Label label){
+	protected Map<VerificationField, List<?>> encodeTargetValues(RGenericVector dataFrame, ScalarLabel scalarLabel){
 		List<RExp> columns = dataFrame.getValues();
-		FieldName name = label.getName();
+		String name = scalarLabel.getName();
 
 		return encodeVerificationData(columns, Collections.singletonList(name));
 	}
@@ -141,19 +162,15 @@ public class ModelConverter<R extends RExp> extends Converter<R> {
 		List<RExp> columns = dataFrame.getValues();
 		RStringVector columnNames = dataFrame.names();
 
-		List<FieldName> names = (columnNames.getDequotedValues()).stream()
-			.map(columnName -> FieldName.create(columnName))
-			.collect(Collectors.toList());
-
-		return encodeVerificationData(columns, names);
+		return encodeVerificationData(columns, columnNames.getDequotedValues());
 	}
 
 	static
-	protected Map<VerificationField, List<?>> encodeVerificationData(List<? extends RExp> columns, List<FieldName> names){
+	protected Map<VerificationField, List<?>> encodeVerificationData(List<? extends RExp> columns, List<String> names){
 		Map<VerificationField, List<?>> result = new LinkedHashMap<>();
 
 		for(int i = 0; i < columns.size(); i++){
-			FieldName name = names.get(i);
+			String name = names.get(i);
 			RVector<?> column = (RVector<?>)columns.get(i);
 
 			List<?> values;
