@@ -26,7 +26,6 @@ import org.dmg.pmml.DataField;
 import org.dmg.pmml.DataType;
 import org.dmg.pmml.DerivedField;
 import org.dmg.pmml.Expression;
-import org.dmg.pmml.FieldName;
 import org.dmg.pmml.FieldRef;
 import org.dmg.pmml.OpType;
 import org.dmg.pmml.PMMLFunctions;
@@ -41,12 +40,13 @@ import org.jpmml.converter.Feature;
 import org.jpmml.converter.FieldNameUtil;
 import org.jpmml.converter.FortranMatrix;
 import org.jpmml.converter.ModelUtil;
-import org.jpmml.converter.OutlierTransformation;
 import org.jpmml.converter.PMMLUtil;
 import org.jpmml.converter.Schema;
+import org.jpmml.converter.SchemaUtil;
 import org.jpmml.converter.Transformation;
 import org.jpmml.converter.ValueUtil;
 import org.jpmml.converter.support_vector_machine.LibSVMUtil;
+import org.jpmml.converter.transformations.OutlierTransformation;
 
 public class SVMConverter extends ModelConverter<RGenericVector> {
 
@@ -107,9 +107,9 @@ public class SVMConverter extends ModelConverter<RGenericVector> {
 					};
 
 					supportVectorMachineModel = encodeRegression(pmmlKernel, sv, rho, coefs, schema)
-						.setOutput(ModelUtil.createPredictedOutput(FieldName.create("decisionFunction"), OpType.CONTINUOUS, DataType.DOUBLE, outlier));
+						.setOutput(ModelUtil.createPredictedOutput("decisionFunction", OpType.CONTINUOUS, DataType.DOUBLE, outlier));
 
-					if(yScale != null && yScale.size() > 0){
+					if(yScale != null && !yScale.isEmpty()){
 						throw new IllegalArgumentException();
 					}
 				}
@@ -119,7 +119,7 @@ public class SVMConverter extends ModelConverter<RGenericVector> {
 				{
 					supportVectorMachineModel = encodeRegression(pmmlKernel, sv, rho, coefs, schema);
 
-					if(yScale != null && yScale.size() > 0){
+					if(yScale != null && !yScale.isEmpty()){
 						RDoubleVector yScaledCenter = yScale.getDoubleElement("scaled:center");
 						RDoubleVector yScaledScale = yScale.getDoubleElement("scaled:scale");
 
@@ -158,7 +158,7 @@ public class SVMConverter extends ModelConverter<RGenericVector> {
 				FormulaUtil.setLabel(formula, terms, levels, encoder);
 				break;
 			case ONE_CLASSIFICATION:
-				encoder.setLabel(new ContinuousLabel(null, DataType.DOUBLE));
+				encoder.setLabel(new ContinuousLabel(DataType.DOUBLE));
 				break;
 			case EPS_REGRESSION:
 			case NU_REGRESSION:
@@ -184,28 +184,26 @@ public class SVMConverter extends ModelConverter<RGenericVector> {
 		RStringVector columnNames = sv.dimnames(1);
 
 		{
-			FieldName name = FieldName.create("_target");
-
 			switch(svmType){
 				case C_CLASSIFICATION:
 				case NU_CLASSIFICATION:
 					{
 						RStringVector stringLevels = (RStringVector)levels;
 
-						DataField dataField = encoder.createDataField(name, OpType.CATEGORICAL, DataType.STRING, stringLevels.getValues());
+						DataField dataField = encoder.createDataField("_target", OpType.CATEGORICAL, DataType.STRING, stringLevels.getValues());
 
 						encoder.setLabel(dataField);
 					}
 					break;
 				case ONE_CLASSIFICATION:
 					{
-						encoder.setLabel(new ContinuousLabel(null, DataType.DOUBLE));
+						encoder.setLabel(new ContinuousLabel(DataType.DOUBLE));
 					}
 					break;
 				case EPS_REGRESSION:
 				case NU_REGRESSION:
 					{
-						DataField dataField = encoder.createDataField(name, OpType.CONTINUOUS, DataType.DOUBLE);
+						DataField dataField = encoder.createDataField("_target", OpType.CONTINUOUS, DataType.DOUBLE);
 
 						encoder.setLabel(dataField);
 					}
@@ -216,7 +214,7 @@ public class SVMConverter extends ModelConverter<RGenericVector> {
 		for(int i = 0; i < columnNames.size(); i++){
 			String columnName = columnNames.getValue(i);
 
-			DataField dataField = encoder.createDataField(FieldName.create(columnName), OpType.CONTINUOUS, DataType.DOUBLE);
+			DataField dataField = encoder.createDataField(columnName, OpType.CONTINUOUS, DataType.DOUBLE);
 
 			encoder.addFeature(dataField);
 		}
@@ -236,9 +234,7 @@ public class SVMConverter extends ModelConverter<RGenericVector> {
 
 		List<Feature> features = encoder.getFeatures();
 
-		if((scaled.size() != columnNames.size()) || (scaled.size() != features.size())){
-			throw new IllegalArgumentException();
-		}
+		SchemaUtil.checkSize(scaled.size(), features);
 
 		RDoubleVector xScaledCenter = xScale.getDoubleElement("scaled:center");
 		RDoubleVector xScaledScale = xScale.getDoubleElement("scaled:scale");
