@@ -22,7 +22,6 @@ import java.util.List;
 
 import org.dmg.pmml.DataField;
 import org.dmg.pmml.DataType;
-import org.dmg.pmml.FieldName;
 import org.dmg.pmml.OpType;
 import org.jpmml.converter.CategoricalLabel;
 import org.jpmml.converter.Label;
@@ -35,18 +34,20 @@ public class Classification extends ObjFunction {
 	private int num_class;
 
 
-	public Classification(int num_class){
+	public Classification(String name, int num_class){
+		super(name);
+
 		this.num_class = num_class;
 	}
 
 	@Override
-	public Label encodeLabel(FieldName targetField, List<?> targetCategories, PMMLEncoder encoder){
+	public Label encodeLabel(String targetName, List<?> targetCategories, PMMLEncoder encoder){
 		DataField dataField;
 
 		if(targetCategories == null){
 			targetCategories = LabelUtil.createTargetCategories(this.num_class);
 
-			dataField = encoder.createDataField(targetField, OpType.CATEGORICAL, DataType.INTEGER, targetCategories);
+			dataField = encoder.createDataField(targetName, OpType.CATEGORICAL, DataType.INTEGER, targetCategories);
 		} else
 
 		{
@@ -54,7 +55,7 @@ public class Classification extends ObjFunction {
 				throw new IllegalArgumentException("Expected " + this.num_class + " target categories, got " + targetCategories.size() + " target categories");
 			}
 
-			dataField = encoder.createDataField(targetField, OpType.CATEGORICAL, DataType.STRING, targetCategories);
+			dataField = encoder.createDataField(targetName, OpType.CATEGORICAL, DataType.STRING, targetCategories);
 		}
 
 		return new CategoricalLabel(dataField);
