@@ -20,9 +20,15 @@ package org.jpmml.xgboost;
 
 import java.io.IOException;
 import java.util.Arrays;
+import java.util.BitSet;
+import java.util.HashSet;
+import java.util.Set;
 
+import com.devsmart.ubjson.GsonUtil;
+import com.devsmart.ubjson.UBArray;
+import com.devsmart.ubjson.UBObject;
+import com.devsmart.ubjson.UBValue;
 import com.google.common.primitives.Floats;
-import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 import org.dmg.pmml.mining.MiningModel;
 import org.jpmml.converter.Schema;
@@ -71,32 +77,85 @@ public class GBTree extends GradientBooster {
 
 	@Override
 	public void loadJSON(JsonObject gradientBooster){
-		JsonObject model = gradientBooster.getAsJsonObject("model");
+		UBValue value = GsonUtil.toUBValue(gradientBooster);
 
-		JsonObject gbtreeModelParam = model.getAsJsonObject("gbtree_model_param");
+		loadUBJSON(value.asObject());
+	}
 
-		this.num_trees = gbtreeModelParam.getAsJsonPrimitive("num_trees").getAsInt();
-		this.size_leaf_vector = gbtreeModelParam.getAsJsonPrimitive("size_leaf_vector").getAsInt();
+	@Override
+	public void loadUBJSON(UBObject gradientBooster){
+		UBObject model = gradientBooster.get("model").asObject();
 
-		JsonArray trees = model.getAsJsonArray("trees");
+		UBObject gbtreeModelParam = model.get("gbtree_model_param").asObject();
+
+		this.num_trees = gbtreeModelParam.get("num_trees").asInt();
+		this.size_leaf_vector = gbtreeModelParam.get("size_leaf_vector").asInt();
+
+		UBArray trees = model.get("trees").asArray();
 
 		this.trees = new RegTree[this.num_trees];
 
 		for(int i = 0; i < this.num_trees; i++){
-			JsonObject tree = (trees.get(i)).getAsJsonObject();
+			UBObject tree = (trees.get(i)).asObject();
 
 			this.trees[i] = new RegTree();
-			this.trees[i].loadJSON(tree);
+			this.trees[i].loadUBJSON(tree);
 		}
 
-		this.tree_info = JSONUtil.toIntArray(model.getAsJsonArray("tree_info"));
+		this.tree_info = UBJSONUtil.toIntArray(model.get("tree_info"));
 	}
 
-	public MiningModel encodeMiningModel(ObjFunction obj, float base_score, Integer ntreeLimit, Schema schema){
+	public boolean hasCategoricalSplits(){
+
+		for(int i = 0; i < this.num_trees; i++){
+			RegTree tree = this.trees[i];
+
+			if(tree.hasCategoricalSplits()){
+				return true;
+			}
+		}
+
+		return false;
+	}
+
+	public Set<Integer> getSplitType(int splitIndex){
+		Set<Integer> result = new HashSet<>();
+
+		for(int i = 0; i < this.num_trees; i++){
+			RegTree tree = this.trees[i];
+
+			result.addAll(tree.getSplitType(splitIndex));
+		}
+
+		return result;
+	}
+
+	public BitSet getSplitCategories(int splitIndex){
+		BitSet result = null;
+
+		for(int i = 0; i < this.num_trees; i++){
+			RegTree tree = this.trees[i];
+
+			BitSet splitCategories = tree.getSplitCategories(splitIndex);
+
+			if(splitCategories != null){
+
+				if(result == null){
+					result = new BitSet();
+				}
+
+				result.or(splitCategories);
+			}
+		}
+
+		return result;
+	}
+
+	public MiningModel encodeMiningModel(ObjFunction obj, float base_score, Integer ntreeLimit, boolean numeric, Schema schema){
 		RegTree[] trees = trees();
 		float[] weights = tree_weights();
 
-		return obj.encodeMiningModel(Arrays.asList(trees), weights != null ? Floats.asList(weights) : null, base_score, ntreeLimit, schema);
+		return obj.encodeMiningModel(Arrays.asList(trees), weights != null ? Floats.asList(weights) : null, base_score, ntreeLimit, numeric, schema);
 	}
 
 	public int num_trees(){
