@@ -32,10 +32,14 @@ public interface HasXGBoostOptions extends HasOptions, HasNativeConfiguration {
 
 	String OPTION_COMPACT = "compact";
 
-	String OPTION_NAN_AS_MISSING = "nan_as_missing";
+	String OPTION_MISSING = "missing";
 
 	String OPTION_NTREE_LIMIT = "ntree_limit";
 
+	String OPTION_NUMERIC = "numeric";
+
+	String OPTION_PRUNE = "prune";
+
 	@Override
 	default
 	public Map<String, ?> getNativeConfiguration(){
