@@ -25,9 +25,13 @@ import org.jpmml.converter.Schema;
 
 public class LambdaMART extends Regression {
 
+	public LambdaMART(String name){
+		super(name);
+	}
+
 	@Override
-	public MiningModel encodeMiningModel(List<RegTree> trees, List<Float> weights, float base_score, Integer ntreeLimit, Schema schema){
-		MiningModel miningModel = createMiningModel(trees, weights, base_score, ntreeLimit, schema);
+	public MiningModel encodeMiningModel(List<RegTree> trees, List<Float> weights, float base_score, Integer ntreeLimit, boolean numeric, Schema schema){
+		MiningModel miningModel = createMiningModel(trees, weights, base_score, ntreeLimit, numeric, schema);
 
 		return miningModel;
 	}
